package com.malk.junengtai.service;

import com.fasterxml.jackson.core.JacksonException;
import com.malk.server.common.McR;

import java.util.Map;

public interface PurchaseService {

    /*手动同步档案表数据*/
    McR synchronizedArchiveTable(String name,String date) throws JacksonException;

    /*同步组件信息*/
    McR ComponentInformation(String date) throws JacksonException;

    /*供应商信息*/
    McR supplierInformation(String dateString1) throws  JacksonException;

    /*查询库存信息*/
    McR queryInventory(Map<String,String> body) throws JacksonException;

    /*创建采购订单接口*/
    McR purchaseOrder(String instanceId) throws  JacksonException;

    /*查询拣货单接口*/
    Map pickingList(Map<String,String> body) throws JacksonException;
}
